@@ -20,12 +20,12 @@ logging.basicConfig(
     datefmt="%Y-%m-%d %H:%M:%S",
 )
 
-from .client import Client, ExportRequest, SeriesInfo  # NOQA: E402
-from .config import ServerConfig, register_server  # NOQA: E402
-from .exceptions import DrmsError, DrmsExportError, DrmsOperationNotSupported, DrmsQueryError  # NOQA: E402
-from .json import HttpJsonClient, HttpJsonRequest, JsocInfoConstants  # NOQA: E402
-from .utils import to_datetime  # NOQA: E402
-from .version import version as __version__  # NOQA: E402
+from .client import Client, ExportRequest, SeriesInfo
+from .config import ServerConfig, register_server
+from .exceptions import DrmsError, DrmsExportError, DrmsOperationNotSupported, DrmsQueryError
+from .json import HttpJsonClient, HttpJsonRequest, JsocInfoConstants
+from .utils import to_datetime
+from .version import version as __version__
 
 
 def _get_bibtex():
@@ -46,9 +46,6 @@ def _get_bibtex():
 __citation__ = __bibtex__ = _get_bibtex()
 
 __all__ = [
-    "__bibtex__",
-    "__citation__",
-    "__version__",
     "Client",
     "DrmsError",
     "DrmsExportError",
@@ -58,9 +55,12 @@ __all__ = [
     "HttpJsonClient",
     "HttpJsonRequest",
     "JsocInfoConstants",
-    "register_server",
     "SeriesInfo",
     "ServerConfig",
-    "to_datetime",
+    "__bibtex__",
+    "__citation__",
+    "__version__",
     "logger",
+    "register_server",
+    "to_datetime",
 ]
