@@ -1,22 +1,24 @@
 import os
 import re
 import time
+import shutil
+import socket
 from pathlib import Path
 from collections import OrderedDict
 from urllib.error import URLError, HTTPError
 from urllib.parse import urljoin
-from urllib.request import urlretrieve
+from urllib.request import urlopen
 
 import numpy as np
 import pandas as pd
 
 from drms import logger
-
+from drms.utils import create_request_with_header
 from .exceptions import DrmsExportError, DrmsOperationNotSupported, DrmsQueryError
 from .json import HttpJsonClient
 from .utils import _extract_series_name, _pd_to_numeric_coerce, _split_arg
 
-__all__ = ["SeriesInfo", "ExportRequest", "Client"]
+__all__ = ["Client", "ExportRequest", "SeriesInfo"]
 
 
 class SeriesInfo:
@@ -68,12 +70,7 @@ class SeriesInfo:
     @staticmethod
     def _parse_keywords(d):
         keys = ["name", "type", "recscope", "defval", "units", "note", "linkinfo"]
-        res = []
-        for di in d:
-            resi = []
-            for k in keys:
-                resi.append(di.get(k))
-            res.append(tuple(resi))
+        res = [tuple(di.get(k) for k in keys) for di in d]
         if not res:
             res = None  # workaround for older pandas versions
         res = pd.DataFrame(res, columns=keys)
@@ -90,12 +87,7 @@ class SeriesInfo:
     @staticmethod
     def _parse_links(d):
         keys = ["name", "target", "kind", "note"]
-        res = []
-        for di in d:
-            resi = []
-            for k in keys:
-                resi.append(di.get(k))
-            res.append(tuple(resi))
+        res = [tuple(di.get(k) for k in keys) for di in d]
         if not res:
             res = None  # workaround for older pandas versions
         res = pd.DataFrame(res, columns=keys)
@@ -105,12 +97,7 @@ class SeriesInfo:
     @staticmethod
     def _parse_segments(d):
         keys = ["name", "type", "units", "protocol", "dims", "note"]
-        res = []
-        for di in d:
-            resi = []
-            for k in keys:
-                resi.append(di.get(k))
-            res.append(tuple(resi))
+        res = [tuple(di.get(k) for k in keys) for di in d]
         if not res:
             res = None  # workaround for older pandas versions
         res = pd.DataFrame(res, columns=keys)
@@ -205,7 +192,7 @@ class ExportRequest:
         # data_dir contains a directory, the filename column should contain
         # only the basename and we need to join it with the directory.
         if data_dir is None:
-            res.rename(columns={"filename": "fpath"}, inplace=True)
+            res = res.rename(columns={"filename": "fpath"})
             split_fpath = res.fpath.str.split("/")
             res["filename"] = [sfp[-1] for sfp in split_fpath]
         else:
@@ -213,8 +200,6 @@ class ExportRequest:
 
         if self.method.startswith("url"):
             baseurl = self._client._server.http_download_baseurl
-        elif self.method.startswith("ftp"):
-            baseurl = self._client._server.ftp_download_baseurl
         else:
             raise RuntimeError(f"Download is not supported for export method {self.method}")
 
@@ -424,7 +409,7 @@ class ExportRequest:
         ----------
         timeout : int or None
             Maximum number of seconds until this method times out. If
-            set to None (the default), the status will be updated
+            set to `None` (the default), the status will be updated
             indefinitely until the request succeeded or failed.
         sleep : int or None
             Time in seconds between status updates (defaults to 5
@@ -485,7 +470,7 @@ class ExportRequest:
                 logger.info(f"Request not found on server, {retries_notfound} retries left.")
                 retries_notfound -= 1
 
-    def download(self, directory, *, index=None, fname_from_rec=None):
+    def download(self, directory, *, index=None, fname_from_rec=None, timeout=60):
         """
         Download data files.
 
@@ -521,6 +506,10 @@ class ExportRequest:
             generated. This also applies to movie files from exports
             with protocols 'mpg' or 'mp4', where the original filename
             is used locally.
+        timeout: float, optional
+            Sets the timeout to "urlopen", this defaults to 60 seconds.
+            This can be overridden if you set the socket timeout using
+            `socket.setdefaulttimeout`.
 
         Returns
         -------
@@ -570,7 +559,12 @@ class ExportRequest:
             logger.info(f"    record: {di.record}")
             logger.info(f"    filename: {di.filename}")
             try:
-                urlretrieve(di.url, fpath_tmp)
+                timeout = socket.getdefaulttimeout() or timeout
+                with (
+                    urlopen(create_request_with_header(di.url), timeout=timeout) as response,
+                    open(fpath_tmp, "wb") as out_file,
+                ):
+                    shutil.copyfileobj(response, out_file)
             except (HTTPError, URLError):
                 fpath_new = None
                 logger.info("    -> Error: Could not download file")
