@@ -27,7 +27,6 @@ class ServerConfig:
         url_show_series_wrapper
         encoding
         http_download_baseurl
-        ftp_download_baseurl
 
     Parameters
     ----------
@@ -54,7 +53,6 @@ class ServerConfig:
         "url_show_series_wrapper",
         "encoding",
         "http_download_baseurl",
-        "ftp_download_baseurl",
     )
 
     def __init__(self, config=None, **kwargs):
@@ -84,7 +82,7 @@ class ServerConfig:
                     d[url_key] = urljoin(cgi_baseurl, cgi_value)
 
     def __repr__(self):
-        return f'<ServerConfig: {self._d.get("name")}>'
+        return f"<ServerConfig: {self._d.get('name')}>"
 
     def __dir__(self):
         return dir(type(self)) + list(self.__dict__.keys()) + list(self._valid_keys)
@@ -151,7 +149,6 @@ register_server(
         cgi_show_series_wrapper="showextseries",
         show_series_wrapper_dbhost="hmidb2",
         http_download_baseurl="http://jsoc.stanford.edu/",
-        ftp_download_baseurl="ftp://pail.stanford.edu/export/",
     ),
 )
 
