@@ -1,14 +1,14 @@
 import json as _json
+import socket
 from enum import Enum
 from urllib.parse import urlencode, quote_plus
 from urllib.request import HTTPError, urlopen
 
 from drms import logger
-
 from .config import ServerConfig, _server_configs
-from .utils import _split_arg
+from .utils import _split_arg, create_request_with_header
 
-__all__ = ["JsocInfoConstants", "HttpJsonRequest", "HttpJsonClient"]
+__all__ = ["HttpJsonClient", "HttpJsonRequest", "JsocInfoConstants"]
 
 
 # TODO: When we support 3.11, we can use StrEnum instead of Enum
@@ -37,10 +37,11 @@ class HttpJsonRequest:
     Use `HttpJsonClient` to create an instance.
     """
 
-    def __init__(self, url, encoding):
+    def __init__(self, url, encoding, timeout=60):
+        timeout = socket.getdefaulttimeout() or timeout
         self._encoding = encoding
         try:
-            self._http = urlopen(url)
+            self._http = urlopen(create_request_with_header(url), timeout=timeout)
         except HTTPError as e:
             e.msg = f"Failed to open URL: {e.url} with {e.code} - {e.msg}"
             raise e
@@ -161,7 +162,7 @@ class HttpJsonClient:
         result : dict
             Dictionary containing information about the data series.
         """
-        query = f'?{urlencode({"op": "series_struct", "ds": ds})}'
+        query = f"?{urlencode({'op': 'series_struct', 'ds': ds})}"
         req = self._json_request(self._server.url_jsoc_info + query)
         return req.data
 
@@ -179,7 +180,7 @@ class HttpJsonClient:
         result : dict
             Dictionary containing 'count', 'status' and 'runtime'.
         """
-        query = f'?{urlencode({"op": "rs_summary", "ds": ds})}'
+        query = f"?{urlencode({'op': 'rs_summary', 'ds': ds})}"
         req = self._json_request(self._server.url_jsoc_info + query)
         return req.data
 
@@ -356,9 +357,9 @@ class HttpJsonClient:
                         raise ValueError(f"Unknown protocol argument: {k}")
             protocol += ",CT={ct},scaling={scaling},size={size}".format(**extra_keys)
             if "min" in extra_keys:
-                protocol += f',min={extra_keys["min"]:g}'
+                protocol += f",min={extra_keys['min']:g}"
             if "max" in extra_keys:
-                protocol += f',max={extra_keys["max"]:g}'
+                protocol += f",max={extra_keys['max']:g}"
         else:
             if protocol_args is not None:
                 raise ValueError(f"protocol_args not supported for protocol {protocol}")
@@ -394,7 +395,7 @@ class HttpJsonClient:
                     raise ValueError(f"{p} is not one of the allowed processing options: {allowed_processes}")
                 process_strings[p] = ",".join([f"{k}={v}" for k, v in opts.items()])
             processes = "|".join([f"{k},{v}" for k, v in process_strings.items()])
-            d["process=n"] = f'{d["process=n"]}|{processes}'
+            d["process=n"] = f"{d['process=n']}|{processes}"
 
         if requester is None:
             d["requester"] = notify.split("@")[0]
@@ -418,6 +419,6 @@ class HttpJsonClient:
         result : dict
             Dictionary containing the export request status.
         """
-        query = f'?{urlencode({"op": "exp_status", "requestid": requestid})}'
+        query = f"?{urlencode({'op': 'exp_status', 'requestid': requestid})}"
         req = self._json_request(self._server.url_jsoc_fetch + query)
         return req.data
