@@ -8,15 +8,30 @@ import drms
 @pytest.mark.parametrize(
     "symbol",
     [
+        "__bibtex__",
+        "__citation__",
+        "__version__",
+        "client",
+        "Client",
+        "config",
         "DrmsError",
-        "DrmsQueryError",
         "DrmsExportError",
         "DrmsOperationNotSupported",
-        "SeriesInfo",
+        "DrmsQueryError",
+        "exceptions",
         "ExportRequest",
-        "Client",
-        "const",
+        "HttpJsonClient",
+        "HttpJsonRequest",
+        "JsocInfoConstants",
+        "json",
+        "main",
+        "Path",
+        "register_server",
+        "SeriesInfo",
+        "ServerConfig",
         "to_datetime",
+        "utils",
+        "version",
     ],
 )
 def test_symbols(symbol):
