@@ -1,8 +1,8 @@
 import pytest
 
 
-@pytest.mark.jsoc
-@pytest.mark.remote_data
+@pytest.mark.jsoc()
+@pytest.mark.remote_data()
 def test_series_list_all(jsoc_client):
     slist = jsoc_client.series()
     assert isinstance(slist, list)
@@ -14,8 +14,8 @@ def test_series_list_all(jsoc_client):
     assert "mdi.fd_v" in (s.lower() for s in slist)
 
 
-@pytest.mark.jsoc
-@pytest.mark.remote_data
+@pytest.mark.jsoc()
+@pytest.mark.remote_data()
 @pytest.mark.parametrize("schema", ["aia", "hmi", "mdi"])
 def test_series_list_schemata(jsoc_client, schema):
     regex = rf"{schema}\."
