@@ -5,7 +5,7 @@ from drms.utils import _extract_series_name, _pd_to_datetime_coerce, _pd_to_nume
 
 
 @pytest.mark.parametrize(
-    "in_obj, expected",
+    ("in_obj", "expected"),
     [
         ("", []),
         ("asd", ["asd"]),
@@ -13,7 +13,6 @@ from drms.utils import _extract_series_name, _pd_to_datetime_coerce, _pd_to_nume
         ("aa, bb, cc", ["aa", "bb", "cc"]),
         (" aa,bb,  cc, dd", ["aa", "bb", "cc", "dd"]),
         ("aa,\tbb,cc, dd ", ["aa", "bb", "cc", "dd"]),
-        ("aa,\tbb,cc, dd ", ["aa", "bb", "cc", "dd"]),
         ([], []),
         (["a", "b", "c"], ["a", "b", "c"]),
         (("a", "b", "c"), ["a", "b", "c"]),
@@ -27,7 +26,7 @@ def test_split_arg(in_obj, expected):
 
 
 @pytest.mark.parametrize(
-    "ds_string, expected",
+    ("ds_string", "expected"),
     [
         ("hmi.v_45s", "hmi.v_45s"),
         ("hmi.v_45s[2010.05.01_TAI]", "hmi.v_45s"),
@@ -41,7 +40,7 @@ def test_extract_series(ds_string, expected):
 
 
 @pytest.mark.parametrize(
-    "arg, exp",
+    ("arg", "exp"),
     [
         (pd.Series(["1.0", "2", -3]), pd.Series([1.0, 2.0, -3.0])),
         (pd.Series(["1.0", "apple", -3]), pd.Series([1.0, float("nan"), -3.0])),
@@ -52,12 +51,12 @@ def test_pd_to_numeric_coerce(arg, exp):
 
 
 @pytest.mark.parametrize(
-    "arg, exp",
+    ("arg", "exp"),
     [
         (
             pd.Series(["2016-04-01 00:00:00", "2016-04-01 06:00:00"]),
             pd.Series([pd.Timestamp("2016-04-01 00:00:00"), pd.Timestamp("2016-04-01 06:00:00")]),
-        )
+        ),
     ],
 )
 def test_pd_to_datetime_coerce(arg, exp):
