@@ -22,4 +22,4 @@ hmi_series = client.series(regex=r"hmi\.", full=True)
 # Print series names, prime-keys (pkeys) and notes
 for series in hmi_series.index:
     print("Series:", hmi_series.name[series])
-    print(" Notes:", (f'\n{8 * " "}').join(textwrap.wrap(hmi_series.note[series])))
+    print(" Notes:", (f"\n{8 * ' '}").join(textwrap.wrap(hmi_series.note[series])))
